<!--This documentation was autogenerated with `python -m royalnet.generate -f markdown`.-->

# `royalpack`

## Commands

### `ciaoruozi`

Saluta Ruozi, un leggendario essere che una volta era in User Games.

### `color`

Invia un colore in chat...?

### `cv`

Elenca le persone attualmente connesse alla chat vocale.

### `diario`

Aggiungi una citazione al Diario.

### `rage`

Arrabbiati per qualcosa, come una software house californiana.

> Aliases: `balurage` `madden` 

### `reminder`

Ti ricorda di fare qualcosa dopo un po' di tempo.

> Aliases: `calendar` 

### `ship`

Crea una ship tra due nomi.

### `smecds`

Secondo me, è colpa dello stagista...

> Aliases: `secondomeecolpadellostagista` 

### `videochannel`

Converti il canale vocale in un canale video.

> Aliases: `golive` `live` `video` 

### `pause`

Metti in pausa o riprendi la riproduzione di un file.

> Aliases: `resume` 

### `play`

Aggiunge un url alla coda della chat vocale.

> Aliases: `p` 

### `queue`

Visualizza la coda di riproduzione attuale..

> Aliases: `q` 

### `skip`

Salta il file attualmente in riproduzione.

> Aliases: `s` 

### `summon`

Evoca il bot in un canale vocale.

> Aliases: `cv` 

### `youtube`

Cerca un video su YouTube e lo aggiunge alla coda della chat vocale.

> Aliases: `yt` 

### `soundcloud`

Cerca un video su SoundCloud e lo aggiunge alla coda della chat vocale.

> Aliases: `sc` 

### `emojify`

Converti un messaggio in emoji.

### `leagueoflegends`

Connetti un account di League of Legends a un account Royalnet, e visualizzane le statistiche.

> Aliases: `lol` `league` 

### `diarioquote`

Cita una riga del diario.

> Aliases: `dq` `quote` `dquote` 

### `peertube`

Guarda quando è uscito l'ultimo video su RoyalTube.

### `googlevideo`

Cerca un video su Google Video e lo aggiunge alla coda della chat vocale.

> Aliases: `gv` 

### `yahoovideo`

Cerca un video su Yahoo Video e lo aggiunge alla coda della chat vocale.

> Aliases: `yv` 

### `userinfo`

Visualizza informazioni su un utente.

> Aliases: `uinfo` `ui` `useri` 

### `spell`

Genera casualmente una spell!

### `ahnonlosoio`

Ah, non lo so io!

### `eat`

Mangia qualcosa!

### `pmots`

Confondi Proto!

## Events

### `discord_cv`

### `discord_summon`

### `discord_play`

### `discord_skip`

### `discord_queue`

### `discord_pause`

## Page Stars

### `/api/user/list`

### `/api/user/get/{uid_str}`

### `/api/diario/list`

### `/api/diario/get/{diario_id}`

## Exception Stars

## Tables

### `diario`

### `aliases`

### `wikipages`

Wiki page properties.

    Warning:
        Requires PostgreSQL!

### `wikirevisions`

A wiki page revision.

    Warning:
        Requires PostgreSQL!

### `bios`

### `reminder`

### `triviascores`

### `mmevents`

### `mmresponse`

### `leagueoflegends`

